19.2 Communications between components, such as between the application server and the database server, should be encrypted, particularly when the components are in different containers or on different systems.